@@ -1,8 +1,7 @@
 package Reddit::Client;
 
-# Remember to include new version and date in the docs, or get rid of that 
-# section altogether
-our $VERSION = '1.341'; # 7/30 removed warnings, they're stupid
+our $VERSION = '1.35';  # 10/02/19 1.35 add_approved_user, minor housekeeping
+# 1.341 7/30 removed warnings, they're stupid
 # 7/30 mute and unmute 
 # 1.33 7/10 corrected 'edited' to not be boolean
 # 5/29 1.32 unban
@@ -15,10 +14,6 @@ our $VERSION = '1.341'; # 7/30 removed warnings, they're stupid
 # 1.31 added a bunch of flags to Link, Thing, Comment, SubReddit
 #	   get_user now accepts 'username' as well as 'user'
 # 	   TODO: make this an alias across more functions, like sub/subreddit is
-# 1.30 -added flair_post and flair_user
-# 1.30 -set_post_flair and set_user_flair have been renamed select_post_flair
-# 		 and select_user_flair respectively, to distinguish them from the new 
-# 		 flair functions and make their functionality more clear.
 
 # TODO: make ispost, iscomment and get_type static
 
@@ -808,13 +803,19 @@ sub ignore_reports {
 	);
 	return $result;
 }
-# ban uses the "modcontributors" oauth scope
+# -ban uses the "modcontributors" oauth scope EXCEPT:
+#   -moderator and moderator_invite use "modothers"
+#   -wikibanned and wikicontributor require both modcontributors and modwiki
+# https://old.reddit.com/dev/api/#POST_api_friend
+#
+# -ban is really a call to friend, which creates relationships between accounts.
+# other functions can call it and pass in a different mode (see functions below)
 sub ban {
 	my ($self, %param) = @_;
 	my $sub	= $param{sub} || $param{subreddit} || die "subreddit is required\n";
 	
 	my $data = {}; 
-	$data->{name}	= $param{username} || die "username is required\n";
+	$data->{name} = $param{user} || $param{username} || die "username is required\n";
 	# ban_context = fullname, but of what - not required
 
 	# Ban message
@@ -848,9 +849,14 @@ sub ban {
 		$data->{duration} = $param{duration} if $param{duration};
 	}
 	# $data->{permissions} = ?
-	# type: one of (friend, moderator, moderator_invite, contributor, banned, muted, wikibanned, wikicontributor)
+	# one of (friend, moderator, moderator_invite, contributor, banned, muted, wikibanned, wikicontributor)
 	if ($param{mode} eq 'mute') {
 		$data->{type} = 'muted';
+	} elsif ($param{mode} eq 'contributor') {
+		$data->{type} = 'contributor';
+	} elsif ($param{mode} eq 'moderator_invite') {
+		print "modinvite\n";
+		$data->{type} = 'moderator_invite';
 	} else {
 		$data->{type} = 'banned';
 	}
@@ -869,6 +875,18 @@ sub mute {
 	return $self->ban(%param);
 }
 
+sub add_approved_user {
+	my ($self, %param) = @_;
+	$param{mode} = 'contributor';
+	return $self->ban(%param);
+}
+# Requires scope 'modothers'
+sub invite_moderator {
+	my ($self, %param) = @_;
+	$param{mode} = 'moderator_invite';
+	return $self->ban(%param);
+}
+
 sub unban {
 	my ($self, %param) = @_;
 	my $sub	= $param{sub} || $param{subreddit} || die "subreddit is required\n";
@@ -1797,14 +1815,20 @@ Note that 'before' and 'after' mean before and after I<in the listing>, not nece
 
 =head1 MISC
 
-All functions that take the parameter C<subreddit> also accept the alias C<sub>.
+All functions that take the parameter C<subreddit> also accept the alias C<sub>. I<Most> functions that take the parameter C<username> also take the alias C<user> (planned to be all soon).
 
-This guide indicates optional arguments with brackets ([]), a convention we borrowed from from PHP's online manual. This creates some slight overlap with Perl's brackets, which are used to indicate an anonymous array reference, however which of the two is intended should be clear from the context.
+This guide indicates optional arguments with brackets ([]), a convention we borrowed from from PHP's online manual. This creates some slight overlap with Perl's brackets (which are used to indicate an anonymous array reference), however which of the two is intended should be clear from the context.
 
 =head1 METHODS
 
 =over
 
+=item add_approved_user
+
+    add_approved_user ( sub => $subreddit, user => $username )
+
+Add an approved user to a subreddit (moderator action).
+
 =item approve
 
     approve ( $fullname )
@@ -1993,7 +2017,7 @@ or
 
     get_comments ( url => $url )
 
-Get the comment tree for the selected subreddit/link_id, subreddit/link_id/comment_id, permalink, or URL. This will be a mix of Comment and MoreComments objects, which are placeholders for collapsed comments. This is analogous to the "show more comments" links on the website.
+Get the comment tree for the selected subreddit/link_id, subreddit/link_id/comment_id, permalink, or URL. This will be a mix of Comment and MoreComments objects, which are placeholders for collapsed comments. They correspond to the "show more comments" links on the website.
 
 If you already have a Link or Comment object, it's best to call its own C<get_comments> method, which takes no arguments and supplies all of the necessary information for you. If you do decide to use this version:
 
